@@ -1,5 +1,8 @@
 #!/usr/bin/perl -T
 
+use 5.006;
+use v5.8;
+
 use strict;
 use warnings;
 
